@@ -1,6 +1,6 @@
 import sys
 from sqlalchemy import create_engine
-sys.path.extend(['../src/yamlbase'])
+sys.path.extend(['../src/yamlbase.py'])
 
 from sql import SQLite
 from src.yamlbase.yaml_worker import YamlDataBaseWorker
